AuthSDK class

Constructors

AuthSDK()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

googleSignIn() Future<User>
login(String email, String password) Future<User>
register({required String name, required String email, required String password, required String gender, required String mobile}) Future<User>