UserModel class

Inheritance

Constructors

UserModel({required String id, required String name, required String email, required String token})
UserModel.fromGoogle({required String email, required String name, required String token})
factory
UserModel.fromJson(Map<String, dynamic> json)
factory

Properties

email String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited