User class

Implementers

Constructors

User({required String id, required String name, required String email, required String token})

Properties

email String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited